pub struct FrameCounter { /* private fields */ }Expand description
Terminal sink that counts decoded frames (video or audio). Backed by
an Arc<AtomicUsize> so the count can be read from outside the
pipeline even when this sink ends up running on a Queue worker
thread.
Implementations
Sourceimpl FrameCounter
impl FrameCounter